@@ -91,12 +91,17 @@ DEFAULT_INSECURE_PORT = 80
 DEFAULT_MINIMUM_SIZE = 100 * 1024
 DEFAULT_MAXIMUM_SIZE = 5 * 1024 * 1024 * 1024
 
+MAX_CERT_XML_BODY_SIZE = 40*1024 #40 KB
+MIN_CERTIFICATE_NAME_LEN = 3
+MAX_CERTIFICATE_NAME_LEN = 63
+CERTIFICATE_ID_LEN = 16
 DEFAULT_BYTE_INTTERVAL = 102400
 DEFAULT_TASK_INTTERVAL = 100
 DEFAULT_TASK_NUM = 8
 DEFAULT_TASK_QUEUE_SIZE = 20000
+CONNECTION_POOL_SIZE = 10
 
-OBS_SDK_VERSION = '3.24.6.1'
+OBS_SDK_VERSION = '3.25.3'
 
 V2_META_HEADER_PREFIX = 'x-amz-meta-'
 V2_HEADER_PREFIX = 'x-amz-'
